@@ -392,7 +392,6 @@ static void create_menu (Application * app) {
     HildonAppMenu *main_menu;
     GtkWidget *item_new;
     GtkWidget *item_open;
-    GtkWidget *item_close;
     GtkWidget *item_playlist;
     GtkWidget *item_playlist_generators;
     GtkWidget *item_players;
@@ -400,15 +399,14 @@ static void create_menu (Application * app) {
     main_menu = HILDON_APP_MENU (hildon_app_menu_new ());
 
     item_new = makeMenuButton ("New");
-    item_open = makeMenuButton ("Open...");
-    item_playlist = makeMenuButton ("Playlist Options...");
-    item_playlist_generators = makeMenuButton("Generators...");
+    item_open = makeMenuButton ("Open File");
+    item_playlist = makeMenuButton ("Playlist Options");
+    item_playlist_generators = makeMenuButton("Generate Playlist");
     app->menu_item_playlist_copy = makeMenuButton("Copy");
     app->menu_item_playlist_paste = makeMenuButton("Paste");
     app->menu_item_playlist_paste_in_group = makeMenuButton ("Paste in new Group");
     app->menu_item_playlist_cut = makeMenuButton("Cut");
-    item_close = makeMenuButton ("Close");
-    item_players = makeMenuButton ("Choose Player...");
+    item_players = makeMenuButton ("Select Player");
 
     hildon_app_menu_append (main_menu, GTK_BUTTON (item_new));
     hildon_app_menu_append (main_menu, GTK_BUTTON (item_open));
@@ -419,13 +417,10 @@ static void create_menu (Application * app) {
     hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_paste));
     hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_paste_in_group));
     hildon_app_menu_append (main_menu, GTK_BUTTON (app->menu_item_playlist_cut));
-    hildon_app_menu_append( main_menu, GTK_BUTTON (item_close ));
 
     /* Attach the callback functions to the activate signal */
     g_signal_connect_after (G_OBJECT (item_new), "clicked",
         G_CALLBACK (callback_file_new), app);
-    g_signal_connect_after( G_OBJECT( item_close ), "clicked",
-        GTK_SIGNAL_FUNC (cb_mainview_close), app);
     g_signal_connect_after (G_OBJECT (item_open), "clicked",
         GTK_SIGNAL_FUNC (callback_file_open), app);
     g_signal_connect_after (G_OBJECT (item_playlist), "clicked",
