@@ -1,4 +1,4 @@
-/* This file is part of the KDE project
+/* This file is part of the KMPlayer project
  *
  * Copyright (C) 2006-2007 Koos Vriezen <koos.vriezen@gmail.com>
  *
@@ -21,15 +21,8 @@
 #ifndef _KMPLAYER_RP_H_
 #define _KMPLAYER_RP_H_
 
-#include <qobject.h>
-#include <qstring.h>
-
 #include "kmplayerplaylist.h"
-#include "kmplayer_smil.h"
-
-namespace KIO {
-    class Job;
-}
+#include "surface.h"
 
 namespace KMPlayer {
 
@@ -48,28 +41,30 @@ const short id_node_fadein = 156;
 const short id_node_fadeout = 157;
 const short id_node_viewchange = 158;
 const short id_node_animate = 159;
+const short id_node_first = id_node_imfl;
+const short id_node_last = 160;
 
-class Imfl : public Mrl {
+class KMPLAYER_NO_EXPORT Imfl : public Mrl {
 public:
     Imfl (NodePtr & d);
     ~Imfl ();
     KDE_NO_EXPORT virtual const char * nodeName () const { return "imfl"; }
-    virtual NodePtr childFromTag (const QString & tag);
+    virtual Node *childFromTag (const String & tag);
+    virtual void closed ();
     virtual void defer ();      // start loading the images if not yet done
     virtual void activate ();   // start timings, handle paint events
     virtual void finish ();     // end the timings
     virtual void deactivate (); // stop handling paint events
-    virtual void childDone (NodePtr child); // for if no duration_timer set
     KDE_NO_EXPORT virtual bool expose () const { return false; }
-    KDE_NO_EXPORT virtual PlayType playType () const { return play_type_image; }
-    virtual bool handleEvent (EventPtr event);
+    KDE_NO_EXPORT virtual PlayType playType () { return play_type_image; }
+    virtual void message (MessageType msg, void *content=NULL);
     virtual void accept (Visitor *);
+    Surface *surface ();
     void repaint (); // called whenever something changes on image
     Fit fit;        // how to layout images
-    Single width, height;     // cached attributes of head
     unsigned int duration; // cached attributes of head
-    TimerInfoPtrW duration_timer;
-    SurfacePtr surface;
+    Command *duration_timer;
+    SurfacePtrW rp_surface;
     int needs_scene_img;
 };
 
@@ -81,7 +76,7 @@ public:
     virtual void begin ();       // start_timer has expired
     virtual void finish ();      // ?duration_timer has expired?
     virtual void deactivate ();  // disabled
-    virtual bool handleEvent (EventPtr event);
+    virtual void message (MessageType msg, void *content=NULL);
     KDE_NO_EXPORT virtual bool expose () const { return false; }
     int progress;
     Single x, y, w, h;
@@ -89,12 +84,13 @@ public:
     NodePtrW target;
 protected:
     void update (int percentage);
+    void cancelTimers ();
     unsigned int start, duration;
     int steps, curr_step;
-    TimerInfoPtrW start_timer;
-    TimerInfoPtrW duration_timer;
-    TimerInfoPtrW update_timer;
-    ConnectionPtr document_postponed;
+    Command *start_timer;
+    Command *duration_timer;
+    Command *update_timer;
+    ConnectionLink document_postponed;
 };
 
 class KMPLAYER_NO_EXPORT Crossfade : public TimingsBase {
@@ -165,20 +161,23 @@ public:
     virtual void accept (Visitor *);
 };
 
-class KMPLAYER_NO_EXPORT Image : public RemoteObject, public Mrl {
+class KMPLAYER_NO_EXPORT Image : public Mrl {
     PostponePtr postpone_lock;
 public:
     Image (NodePtr & d);
     ~Image ();
     KDE_NO_EXPORT virtual const char * nodeName () const { return "image"; }
     virtual void activate ();
+    virtual void begin ();
     virtual void deactivate ();
     virtual void closed ();
+    virtual void message (MessageType msg, void *content=NULL);
     bool isReady (bool postpone_if_not = false); // is downloading ready
-    CachedImage cached_img;
-    //bool expose () const { return false; }
+    Surface *surface ();
+    SurfacePtrW img_surface;
+    bool expose () const { return false; }
 protected:
-    virtual void remoteReady (QByteArray & data);
+    void dataArrived ();
 };
 
 } // RP namespace
