@@ -6,6 +6,7 @@
 #include <gdk/gdk.h>
 #include <pango/pango-font.h>
 #include <hildon/hildon-defines.h>
+#include <hildon/hildon-gtk.h>
 
 #include "kmplayerplaylist.h"
 #include "kmplayer.h"
@@ -430,45 +431,9 @@ static gboolean delayedUpdateTree (Application *app) {
     return false;
 }
 
-void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
-    if (app->in_tree_update || !selection)
-        return;
-    GtkTreeView *treeview = GTK_TREE_VIEW (app->playlist_view);
-    GtkTreeIter iter;
-    PlayListData * pld = 0L;
-    //g_print ("cb_selection_changed %d\n", app->playlist_data->show_all);
-    if (gtk_tree_selection_get_selected (selection, 0L, &iter)) {
-        GtkTreeModel * model = gtk_tree_view_get_model (treeview);
-        PlayListData * pld = getListData (app, model, &iter);
-        GtkTreePath* path = gtk_tree_model_get_path (model, &iter);
-        gtk_tree_view_scroll_to_cell (treeview, path, NULL, false, 0, 0);
-        Node *node = getNode (pld, path);
-        Mrl *mrl = node ? node->mrl () : NULL;
-        gtk_tree_path_free (path);
-        if (mrl && pld->id > 0 && node == pld->document.ptr() && !mrl->resolved)
-            mrl->activate ();
-        if (mrl && pld->updated_document_version !=
-                mrl->document ()->m_tree_version)
-            g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
-        setInfoContent (app, node, pld->edit_mode);
-        CONTROL(app)->setCurrentSelected (node);
-        if (mrl && pld->id > 0) //FIXME, hack to become less jumpy when changing trees
-            pld->current = node;
-    }
-}
-
-static gboolean delayedJump (Application *app) {
-    GtkTreePath *path;
-    PlayListData * pld = getListDataFromSelection (app, &path);
-    if (pld) {
-        jump (pld->current.ptr (), CONTROL(app));
-        gtk_tree_path_free (path);
-    }
-    return false;
-}
-
 static void
-setPlaylistEdit (Application *app, PlayListData *pld, bool editable) {
+setPlaylistEdit (Application *app, PlayListData *pld, bool editable)
+{
     if (editable) {
         gtk_widget_show (GTK_WIDGET (app->tb_item_playlist_commit));
         gtk_widget_hide (GTK_WIDGET (app->tb_save));
@@ -487,34 +452,94 @@ setPlaylistEdit (Application *app, PlayListData *pld, bool editable) {
     g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
 }
 
-void cb_row_activated (GtkTreeView * tree_view, GtkTreePath *path,
-        GtkTreeViewColumn *arg2, Application * app) {
-    PlayListData *pld = getListData (CONTROL(app), path);
-    Node *node = getNode (pld, path);
-    debugLog() << "row activated" << endl;
+static bool had_selection_change;
 
-    // click outside editable tree
-    for (PlayListData *pd = CONTROL(app)->playlist_data; pd; pd = pd->next)
-        if (pd != pld && (pd->edit_mode || pd->show_all)) {
-            pd->show_all = false;
-            if (pd->edit_mode) {
-                setPlaylistEdit (app, pd, false);
-            } else {
-                pd->updated_document = NULL;
-                g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
+static gboolean cb_tapTimeout (gpointer)
+{
+    had_selection_change = false;
+    return false;
+}
+
+static void cb_selection_changed (GtkTreeSelection *selection, Application *app)
+{
+    if (app->in_tree_update || !selection)
+        return;
+    GtkTreeView *treeview = GTK_TREE_VIEW (app->playlist_view);
+    GtkTreeIter iter;
+    PlayListData * pld = 0L;
+    //g_print ("cb_selection_changed %d\n", app->playlist_data->show_all);
+    if (gtk_tree_selection_get_selected (selection, 0L, &iter)) {
+        GtkTreeModel * model = gtk_tree_view_get_model (treeview);
+        PlayListData * pld = getListData (app, model, &iter);
+        GtkTreePath* path = gtk_tree_model_get_path (model, &iter);
+
+        // click outside editable tree
+        for (PlayListData *pd = CONTROL(app)->playlist_data; pd; pd = pd->next)
+            if (pd != pld && (pd->edit_mode || pd->show_all)) {
+                pd->show_all = false;
+                if (pd->edit_mode) {
+                    setPlaylistEdit (app, pd, false);
+                } else {
+                    pd->updated_document = NULL;
+                    g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer)app);
+                }
+                break;
             }
-            break;
-        }
 
-    if (gtk_tree_path_get_depth (path) != 1) {
-        if (pld->id == 0 || pld->edit_mode)
-            setInfoContent (app, node, pld->edit_mode);
-        if (!pld->edit_mode && (pld->id == 0 || (node && node->mrl ()))) {
-            if (pld->id > 0) {
-                pld->current = node;
-                g_idle_add ((GSourceFunc) delayedJump, (gpointer) app);
-            } else {
-                jump (node, CONTROL(app));
+        gtk_tree_view_scroll_to_cell (treeview, path, NULL, false, 0, 0);
+        Node *node = getNode (pld, path);
+        Mrl *mrl = node ? node->mrl () : NULL;
+        gtk_tree_path_free (path);
+        if (mrl && pld->id > 0 && node == pld->document.ptr() && !mrl->resolved)
+            mrl->activate ();
+        if (mrl && pld->updated_document_version !=
+                mrl->document ()->m_tree_version)
+            g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
+        setInfoContent (app, node, pld->edit_mode);
+        if (mrl && pld->id > 0) //FIXME, hack to become less jumpy when changing trees
+            pld->current = node;
+
+        if (CONTROL(app)->current_selected.ptr () != node) {
+            CONTROL(app)->setCurrentSelected (node);
+            had_selection_change = true;
+            g_timeout_add (200, (GSourceFunc) cb_tapTimeout, NULL);
+        }
+    }
+}
+
+static gboolean delayedJump (Application *app) {
+    GtkTreePath *path;
+    PlayListData * pld = getListDataFromSelection (app, &path);
+    if (pld) {
+        jump (pld->current.ptr (), CONTROL(app));
+        gtk_tree_path_free (path);
+    }
+    return false;
+}
+
+static void
+cb_hildon_row_tapped (GtkTreeView *view, GtkTreePath *path, Application *app)
+{
+    PlayListData *pld = getListData (CONTROL(app), path);
+    if (pld) {
+        Node *node = getNode (pld, path);
+        if (node) {
+            debugLog() << "row activated" << endl;
+            if (gtk_tree_path_get_depth (path) != 1 || pld->id == 0) {
+                if (pld->id == 0 || pld->edit_mode)
+                    setInfoContent (app, node, pld->edit_mode);
+                if (!had_selection_change &&
+                        !pld->edit_mode &&
+                        (pld->id == 0 || (node && node->mrl ()))) {
+                    if (pld->id > 0) {
+                        pld->current = node;
+                        g_idle_add ((GSourceFunc) delayedJump, (gpointer) app);
+                    } else {
+                        jump (node, CONTROL(app));
+                    }
+                } else {
+                    had_selection_change = false;
+                }
             }
         }
     }
@@ -630,18 +655,16 @@ void cb_treeCellDataFunc (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell,
     GtkTreeIter parent;
     PlayListData * pld = getListData (app, tree_model, iter);
     if (!gtk_tree_model_iter_parent (tree_model, &parent, iter) ) {
-        g_object_set (G_OBJECT (cell), "cell-background-gtk",
-                app->playlist_view->style->black, 0L);
-        g_object_set (G_OBJECT (cell), "background-gdk",
-                app->playlist_view->style->dark + 1, 0L);
+        g_object_set (G_OBJECT (cell), "underline",
+                PANGO_UNDERLINE_SINGLE, 0L);
+        //g_object_set (G_OBJECT (cell), "scale", 1.2, 0L);
         g_object_set (G_OBJECT (cell), "editable", false, 0L);
         g_object_set (G_OBJECT (cell), "mode",
                 GTK_CELL_RENDERER_MODE_ACTIVATABLE, 0L);
     } else if (pld) {
-        g_object_set (G_OBJECT (cell), "cell-background-gdk",
-                app->playlist_view->style->bg, 0L);
-        g_object_set (G_OBJECT (cell), "background-gdk",
-                app->playlist_view->style->bg, 0L);
+        g_object_set (G_OBJECT (cell), "underline",
+                PANGO_UNDERLINE_NONE, 0L);
+        //g_object_set (G_OBJECT (cell), "scale", 1.0, 0L);
         g_object_set (G_OBJECT (cell), "mode", pld->edit_mode
                 ? GTK_CELL_RENDERER_MODE_EDITABLE
                 : GTK_CELL_RENDERER_MODE_INERT, 0L);
@@ -699,14 +722,14 @@ GtkWidget * createTreeView (Application * app) {
             "filemanager_playlist", 26, (GtkIconLookupFlags)0, 0L);
 
     store = gtk_tree_store_new (3, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_INT);
-    view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
+    view = hildon_gtk_tree_view_new_with_model (HILDON_UI_MODE_EDIT, GTK_TREE_MODEL (store));
     g_object_unref (store);
 
     col = gtk_tree_view_column_new();
     //gtk_tree_view_column_set_title(col, "Title");
 
     app->playlist_cell_renderer = gtk_cell_renderer_pixbuf_new();
-    gtk_cell_renderer_set_fixed_size (app->playlist_cell_renderer, 26, 26);
+    //gtk_cell_renderer_set_fixed_size (app->playlist_cell_renderer, 26, 26);
     gtk_tree_view_column_pack_start(col, app->playlist_cell_renderer, FALSE);
     gtk_tree_view_column_set_attributes(col, app->playlist_cell_renderer,
             "pixbuf", COL_ICON,
@@ -735,7 +758,7 @@ GtkWidget * createTreeView (Application * app) {
     g_signal_connect (G_OBJECT (view),
             "row-expanded", G_CALLBACK (cb_treerow_expanded), app);
     g_signal_connect (G_OBJECT (view),
-            "row-activated", G_CALLBACK (cb_row_activated), app);
+            "hildon-row-tapped", G_CALLBACK (cb_hildon_row_tapped), app);
     g_signal_connect(G_OBJECT (sel),
             "changed", G_CALLBACK (cb_selection_changed), app);
     gtk_tree_view_column_set_cell_data_func (col, app->playlist_cell_renderer,
