@@ -178,7 +178,6 @@ public:
     virtual bool hue (int pos, bool absolute);
     virtual bool contrast (int pos, bool absolute);
     virtual bool brightness (int pos, bool absolute);
-    virtual void setVideoWindow (int x, int y, int w, int h);
 
     void setPlayer (const char *p) { path = p; }
     void setAudioDriver (const char *ao) { audio_driver = ao; }
@@ -194,7 +193,6 @@ private:
     typedef std::list <String> StringList;
     StringList commands;
     String command_chunk;
-    IRect m_rect;
     UnixProcess unix_process;
     int request_seek;
     char outbuf[512];
@@ -230,6 +228,8 @@ public:
     void processStreams ();
     String evaluateScript (const String &script);
 
+    static bool isFlashMimeType (const String &mime);
+
     GTree *streams;
 private:
     GTree *plugins;
